from practicum import McuBoard

RQ_SET_LED    = 0
RQ_GET_SWITCH = 1
RQ_GET_LIGHT  = 2

####################################
class PeriBoard(McuBoard):

    ################################
    def setLed(self, led_no, led_val):
        '''
        Set status of LED led_no on peripheral board to led_val
        '''
	self.usbWrite(RQ_SET_LED, index=led_no, value=led_val)

    ################################
    def setLedValue(self, value):
        '''
        Display value's 3 LSBs on peripheral board's LEDs
        '''
	self.setLed(0,value%2)
	self.setLed(1,value/2%2)
	self.setLed(2,value/4%2)

    ################################
    def getSwitch(self):
        '''
        Return a boolean value indicating whether the switch on the peripheral
        board is currently pressed
        '''
	try:
		switch_input = self.usbRead(RQ_GET_SWITCH,length=1)[0]
	except:
		return "0"
	if (switch_input & 1): #right
		return "r"
	if (switch_input & 2): #down
		return "d"
	if (switch_input & 4): #left
		return "l"
	if (switch_input & 8): #up
		return "u"
	return "0"
	
    ################################
    def getLight(self):
        '''
        Return the current reading of light sensor on peripheral board
        '''
	light = self.usbRead(RQ_GET_LIGHT,length=2)
        return light[0] + light[1]*256
